# Celmech

Celmech is a collection of analytical and semianalytical tools for celestial mechanics, developed by Sam Hadden and Dan Tamayo.

[![Binder](http://mybinder.org/badge.svg)](https://beta.mybinder.org/v2/gh/shadden/celmech/master)
